bbprep.ReorientPanel
====================

.. currentmodule:: bbprep

.. autoclass:: ReorientPanel
   :members:

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ReorientPanel.reassign_functional_groups
   
   

   
   
   